@@ -12,7 +12,6 @@ import annofabcli.common.cli
 import annofabcli.experimental.subcommand_experimental
 import annofabcli.filesystem.subcommand_filesystem
 import annofabcli.input_data.subcommand_input_data
-import annofabcli.inspection_comment.subcommand_inspection_comment
 import annofabcli.instruction.subcommand_instruction
 import annofabcli.job.subcommand_job
 import annofabcli.my_account.subcommand_my_account
@@ -51,7 +50,7 @@ def main(arguments: Optional[list[str]] = None):
             annofabcli.common.cli.load_logging_config_from_args(args)
             argv = sys.argv
             if arguments is not None:
-                argv = ["annofabcli"] + list(arguments)
+                argv = ["annofabcli", *list(arguments)]
             logger.info(f"argv={argv}")
             args.subcommand_func(args)
         except Exception as e:
@@ -76,7 +75,6 @@ def create_parser() -> argparse.ArgumentParser:
     annofabcli.annotation_specs.subcommand_annotation_specs.add_parser(subparsers)
     annofabcli.comment.subcommand_comment.add_parser(subparsers)
     annofabcli.input_data.subcommand_input_data.add_parser(subparsers)
-    annofabcli.inspection_comment.subcommand_inspection_comment.add_parser(subparsers)
     annofabcli.instruction.subcommand_instruction.add_parser(subparsers)
     annofabcli.job.subcommand_job.add_parser(subparsers)
     annofabcli.my_account.subcommand_my_account.add_parser(subparsers)
