@@ -101,9 +101,12 @@ def add_parser(
         group.add_argument("--yes", action="store_true", help="処理中に現れる問い合わせに対して、常に ``yes`` と回答します。")
 
         group.add_argument(
-            "--endpoint_url", type=str, help=f"Annofab WebAPIのエンドポイントを指定します。", default=DEFAULT_ENDPOINT_URL
+            "--endpoint_url", type=str, help="Annofab WebAPIのエンドポイントを指定します。", default=DEFAULT_ENDPOINT_URL
         )
 
+        group.add_argument("--annofab_user_id", type=str, help="Annofabにログインする際のユーザーID")
+        group.add_argument("--annofab_password", type=str, help="Annofabにログインする際のパスワード")
+
         group.add_argument(
             "--logdir",
             type=Path,
@@ -310,6 +313,18 @@ def build_annofabapi_resource(args: argparse.Namespace) -> annofabapi.Resource:
     if endpoint_url != DEFAULT_ENDPOINT_URL:
         logger.info(f"Annofab WebAPIのエンドポイントURL: {endpoint_url}")
 
+    # コマンドライン引数からユーザーIDが指定された場合
+    if args.annofab_user_id is not None:
+        login_user_id: str = args.annofab_user_id
+        if args.annofab_password is not None:
+            return annofabapi.build(login_user_id, args.annofab_password, endpoint_url=endpoint_url)
+        else:
+            # コマンドライン引数にパスワードが指定されなければ、標準入力からパスワードを取得する
+            login_password = ""
+            while login_password == "":
+                login_password = getpass.getpass("Enter Annofab Password: ")
+            return annofabapi.build(login_user_id, login_password, endpoint_url=endpoint_url)
+
     try:
         return annofabapi.build_from_netrc(endpoint_url)
     except AnnofabApiException:
@@ -414,7 +429,7 @@ class ArgumentParser:
         '--format` 引数を追加
         """
         if help_message is None:
-            help_message = f"出力フォーマットを指定します。"
+            help_message = "出力フォーマットを指定します。"
 
         self.parser.add_argument(
             "-f", "--format", type=str, choices=[e.value for e in choices], default=default.value, help=help_message
@@ -468,7 +483,7 @@ class ArgumentParser:
         self.parser.add_argument("-tq", "--task_query", type=str, required=required, help=help_message)
 
 
-class AbstractCommandLineWithConfirmInterface(abc.ABC):
+class AbstractCommandLineWithConfirmInterface(abc.ABC):  # noqa: abstract-base-class-without-abstract-method
     """
     コマンドライン上でpromptを表示するときのインターフェイス
     """
@@ -619,9 +634,9 @@ class PrettyHelpFormatter(argparse.RawTextHelpFormatter, argparse.ArgumentDefaul
 
     def _get_help_string(self, action):
         # 必須な引数には、引数の説明の後ろに"(required)"を付ける
-        help = action.help  # pylint: disable=redefined-builtin
+        help = action.help  # noqa: builtin-variable-shadowing # pylint: disable=redefined-builtin
         if action.required:
-            help += " (required)"
+            help += " (required)"  # noqa: builtin-variable-shadowing
 
         # 不要なデフォルト値（--debug や オプショナルな引数）を表示させないようにする
         # super()._get_help_string の中身を、そのまま持ってきた。
@@ -632,7 +647,7 @@ class PrettyHelpFormatter(argparse.RawTextHelpFormatter, argparse.ArgumentDefaul
                 if action.option_strings or action.nargs in defaulting_nargs:
                     # 以下の条件だけ、annofabcli独自の設定
                     if action.default is not None and not action.const:
-                        help += " (default: %(default)s)"
+                        help += " (default: %(default)s)"  # noqa: builtin-variable-shadowing
         return help
 
 
