@@ -93,7 +93,7 @@ class DownloadingFile:
                 download_annotation_zip()
             except requests.HTTPError as e:
                 if e.response.status_code == requests.codes.not_found:
-                    logger.info(f"アノテーションzipが存在しなかったので、アノテーションzipファイルの更新処理を実行します。")
+                    logger.info("アノテーションzipが存在しなかったので、アノテーションzipファイルの更新処理を実行します。")
                     self.wait_until_updated_annotation_zip(project_id, wait_options)
                     download_annotation_zip()
                 else:
@@ -138,7 +138,7 @@ class DownloadingFile:
                 self.service.wrapper.download_project_inputs_url(project_id, dest_path)
             except requests.HTTPError as e:
                 if e.response.status_code == requests.codes.not_found:
-                    logger.info(f"入力データ全件ファイルが存在しなかったので、入力データ全件ファイルの更新処理を実行します。")
+                    logger.info("入力データ全件ファイルが存在しなかったので、入力データ全件ファイルの更新処理を実行します。")
                     self.wait_until_updated_input_data_json(project_id, wait_options)
                     self.service.wrapper.download_project_inputs_url(project_id, dest_path)
                 else:
@@ -182,7 +182,7 @@ class DownloadingFile:
                 self.service.wrapper.download_project_tasks_url(project_id, dest_path)
             except requests.HTTPError as e:
                 if e.response.status_code == requests.codes.not_found:
-                    logger.info(f"タスク全件ファイルが存在しなかったので、タスク全件ファイルの更新処理を実行します。")
+                    logger.info("タスク全件ファイルが存在しなかったので、タスク全件ファイルの更新処理を実行します。")
                     self.wait_until_updated_task_json(project_id, wait_options)
                     self.service.wrapper.download_project_tasks_url(project_id, dest_path)
                 else:
@@ -298,13 +298,13 @@ class DownloadingFile:
 
     async def download_comment_json_with_async(self, project_id: str, dest_path: str):
         """
-        非同期で検査コメント全件ファイルをダウンロードする。
+        非同期でコメント全件ファイルをダウンロードする。
 
         Raises:
             DownloadingFileNotFoundError:
         """
 
-        return self.download_inspection_comment_json(project_id, dest_path=dest_path)
+        return self.download_comment_json(project_id, dest_path=dest_path)
 
     def download_comment_json(self, project_id: str, dest_path: str):
         """
