@@ -9,7 +9,6 @@ import pandas
 
 import annofabcli
 from annofabcli.common.cli import AbstractCommandLineWithoutWebapiInterface, ArgumentParser, get_list_from_args
-from annofabcli.common.exceptions import AnnofabCliException
 from annofabcli.common.utils import read_multiheader_csv
 
 logger = logging.getLogger(__name__)
@@ -136,7 +135,18 @@ def _get_tuple_column(df: pandas.DataFrame, column: str) -> Union[str, Tuple]:
         return column
 
 
-def replace_by_columns(df, replacement_dict: Dict[str, str], main_column: Any, sub_columns: Optional[List[Any]] = None):
+def replace_by_columns(
+    df: pandas.DataFrame, replacement_dict: Dict[str, str], main_column: Any, sub_columns: Optional[List[Any]] = None
+):
+    """引数dfの中のユーザ情報を、指定した列名を元に置換します。
+
+    Args:
+        df (pandas.DataFrame): _description_
+        replacement_dict (Dict[str, str]): 置換対象のuser_idと置換後のuser_id(username)。key: 置換対象のuser_id, value: 置換後のuser_id
+        main_column: 置換対象の列名(ex: user_id)
+        sub_column: main_columnと同じ値で置換する列(ex: username)
+    """
+
     def _get_username(row, main_column: Any, sub_column: Any) -> str:
         if row[main_column] in replacement_dict:
             return replacement_dict[row[main_column]]
@@ -190,6 +200,9 @@ def get_replaced_biography_set(df: pandas.DataFrame, not_masked_location_set: Op
     if numpy.nan in biography_set:
         biography_set.remove(numpy.nan)
 
+    if pandas.NA in biography_set:
+        biography_set.remove(pandas.NA)
+
     if not_masked_location_set is None:
         return biography_set
     else:
@@ -284,11 +297,13 @@ def replace_biography(
 
 def create_masked_user_info_df(
     df: pandas.DataFrame,
+    *,
     not_masked_biography_set: Optional[Set[str]] = None,
     not_masked_user_id_set: Optional[Set[str]] = None,
 ) -> pandas.DataFrame:
     if "user_id" not in df:
-        raise AnnofabCliException(f"`user_id`列が存在しないため、ユーザ情報をマスクできません。")
+        logger.warning("引数`df`に`user_id`列が存在しないため、ユーザ情報をマスクできません。")
+        return df
 
     df_output = df.copy()
     replacement_dict_by_user_id = create_replacement_dict_by_user_id(
