@@ -16,9 +16,8 @@ from annofabapi.models import ProjectMemberRole
 
 import annofabcli
 import annofabcli.common.cli
-from annofabcli import AnnofabApiFacade
 from annofabcli.common.cli import AbstractCommandLineInterface, build_annofabapi_resource_and_login
-from annofabcli.common.facade import convert_annotation_specs_labels_v2_to_v1
+from annofabcli.common.facade import AnnofabApiFacade, convert_annotation_specs_labels_v2_to_v1
 
 DiffResult = Tuple[bool, str]
 """差分があるかどうかと、差分メッセージ"""
@@ -141,8 +140,8 @@ class DiffProjects(AbstractCommandLineInterface):
 
         diff_message = ""
 
-        duplicated_set1 = annofabcli.utils.duplicated_set(label_names1)
-        duplicated_set2 = annofabcli.utils.duplicated_set(label_names2)
+        duplicated_set1 = annofabcli.common.utils.duplicated_set(label_names1)
+        duplicated_set2 = annofabcli.common.utils.duplicated_set(label_names2)
 
         flag = False
         if len(duplicated_set1) > 0:
@@ -183,7 +182,7 @@ class DiffProjects(AbstractCommandLineInterface):
         is_duplicated, duplicated_message = self.validate_duplicated(label_names1, label_names2)
         diff_message += duplicated_message
         if is_duplicated:
-            diff_message += f"ラベル名(en)が重複しているので、アノテーションラベル情報の差分は確認しません。\n"
+            diff_message += "ラベル名(en)が重複しているので、アノテーションラベル情報の差分は確認しません。\n"
 
         if label_names1 != label_names2:
             diff_message += (
@@ -326,7 +325,6 @@ class DiffProjects(AbstractCommandLineInterface):
         config1 = self.service.api.get_project(project_id1)[0]["configuration"]
         config2 = self.service.api.get_project(project_id2)[0]["configuration"]
 
-        # ignored_key = {"updated_datetime", "created_datetime", "project_id"}
         diff_result = list(dictdiffer.diff(config1, config2))
         if len(diff_result) > 0:
             diff_message += f"### プロジェクト設定に差分あり\n" f"{pprint.pformat(diff_result)}\n"
