@@ -108,8 +108,8 @@ def mask_visualization_dir(
     exclude_masked_user_for_line_graph: bool = False,
 ) -> None:
     user_performance = project_dir.read_user_performance()
-    if user_performance.empty():
-        logger.warning(f"メンバごとの生産性と品質情報が空であるため、ユーザー情報をマスクできません。終了します。")
+    if user_performance.is_empty():
+        logger.warning("メンバごとの生産性と品質情報が空であるため、ユーザー情報をマスクできません。終了します。")
         return
 
     # マスクするユーザの情報を取得する
@@ -181,12 +181,11 @@ def main(args):
 
 
 def parse_args(parser: argparse.ArgumentParser):
-
     parser.add_argument(
         "--dir",
         type=Path,
         required=True,
-        help=f"マスクしたいプロジェクトディレクトリを指定してください。プロジェクトディレクトリは  ``annofabcli statistics visualize`` コマンドの出力結果です。",  # noqa: E501
+        help="マスクしたいプロジェクトディレクトリを指定してください。プロジェクトディレクトリは  ``annofabcli statistics visualize`` コマンドの出力結果です。",  # noqa: E501
     )
 
     parser.add_argument(
