@@ -238,6 +238,9 @@ class CollectingPerformanceInfo:
                 logger.warning(f"{project_dir}からメンバごとの生産性と品質を読み込むのに失敗しました。", exc_info=True)
                 continue
 
+            if user_performance.is_empty():
+                continue
+
             df_performance = user_performance.df.copy()
             df_performance.set_index("user_id", inplace=True)
 
@@ -364,7 +367,7 @@ def create_deviation_df(
 
     df_rank["mean_of_deviation"] = df_rank[project_columns].mean(axis=1)
     df_rank["count_of_project"] = df_rank[project_columns].count(axis=1)
-    df = df_rank[list(user_columns) + [("mean_of_deviation", ""), ("count_of_project", "")] + list(project_columns)]
+    df = df_rank[[*list(user_columns), ("mean_of_deviation", ""), ("count_of_project", ""), *list(project_columns)]]
     if user_ids is not None:
         return df[df[("user_id", "")].isin(user_ids)]
     else:
@@ -400,6 +403,9 @@ def create_user_df(target_dir: Path) -> pandas.DataFrame:
             logger.warning(f"{project_dir}からメンバごとの生産性と品質を読み込むのに失敗しました。", exc_info=True)
             continue
 
+        if user_performance.is_empty():
+            continue
+
         tmp_df_user = user_performance.df[[("user_id", ""), ("username", ""), ("biography", "")]].copy()
         all_user_list.extend(tmp_df_user.to_dict("records"))
 
@@ -417,7 +423,6 @@ class WritingCsv:
         self.user_ids = user_ids
 
     def write(self, df: pandas.DataFrame, csv_basename: str, output_dir: Path):
-
         print_csv(df, str(output_dir / f"{csv_basename}.csv"))
 
         # 偏差値のCSVを出力
@@ -519,7 +524,7 @@ def parse_args(parser: argparse.ArgumentParser):
         "--dir",
         type=Path,
         required=True,
-        help=f"プロジェクトディレクトリが存在するディレクトリを指定してください。",
+        help="プロジェクトディレクトリが存在するディレクトリを指定してください。",
     )
 
     parser.add_argument(
