@@ -15,6 +15,7 @@ import numpy
 import pandas
 from annofabapi.models import TaskStatus
 from bokeh.models import DataRange1d
+from bokeh.models.widgets.markups import Div
 from bokeh.plotting import ColumnDataSource
 from dateutil.parser import parse
 
@@ -308,11 +309,11 @@ class WholeProductivityPerCompletedDate:
         return WholeProductivityPerCompletedDate(sum_df.reset_index())
 
     @staticmethod
-    def _create_div_element() -> bokeh.models.Div:
+    def _create_div_element() -> Div:
         """
         HTMLページの先頭に付与するdiv要素を生成する。
         """
-        return bokeh.models.Div(
+        return Div(
             text="""<h4>用語</h4>
             <p>「X日のタスク数」とは、X日に初めて受入完了状態になったタスクの個数です。</p>
             """
@@ -368,8 +369,8 @@ class WholeProductivityPerCompletedDate:
 
         def create_line_graph(title: str, y_axis_label: str, tooltip_columns: list[str]) -> LineGraph:
             return LineGraph(
-                plot_width=1200,
-                plot_height=600,
+                width=1200,
+                height=600,
                 title=title,
                 x_axis_label="日",
                 x_axis_type="datetime",
@@ -572,10 +573,10 @@ class WholeProductivityPerCompletedDate:
         source = ColumnDataSource(data=df)
 
         for fig_info in fig_info_list:
-            y_info_list: list[dict[str, str]] = fig_info["y_info_list"]  # type: ignore
+            y_info_list: list[dict[str, str]] = fig_info["y_info_list"]  # type: ignore[assignment]
             for index, y_info in enumerate(y_info_list):
                 color = get_color_from_small_palette(index)
-                line_graph: LineGraph = fig_info["line_graph"]  # type: ignore
+                line_graph: LineGraph = fig_info["line_graph"]  # type: ignore[assignment]
                 _plot_and_moving_average(
                     line_graph=line_graph,
                     x_column="dt_date",
@@ -589,7 +590,7 @@ class WholeProductivityPerCompletedDate:
             create_task_line_graph(),
             create_input_data_line_graph(),
         ]
-        line_graph_list.extend([info["line_graph"] for info in fig_info_list])  # type: ignore
+        line_graph_list.extend([info["line_graph"] for info in fig_info_list])  # type: ignore[misc]
 
         for line_graph in line_graph_list:
             line_graph.process_after_adding_glyphs()
@@ -604,8 +605,8 @@ class WholeProductivityPerCompletedDate:
 
         def create_line_graph(title: str, y_axis_label: str, tooltip_columns: list[str]) -> LineGraph:
             return LineGraph(
-                plot_width=1200,
-                plot_height=600,
+                width=1200,
+                height=600,
                 title=title,
                 x_axis_label="日",
                 x_axis_type="datetime",
@@ -670,7 +671,6 @@ class WholeProductivityPerCompletedDate:
             return line_graph
 
         def create_input_data_line_graph() -> LineGraph:
-
             line_graph = create_line_graph(
                 title="日ごとの累積入力データ数と累積作業時間",
                 y_axis_label="入力データ数",
@@ -725,7 +725,6 @@ class WholeProductivityPerCompletedDate:
             return line_graph
 
         def create_worktime_line_graph() -> LineGraph:
-
             line_graph = create_line_graph(
                 title="日ごとの累積作業時間",
                 y_axis_label="作業時間[hour]",
@@ -857,20 +856,18 @@ class WholeProductivityPerCompletedDate:
             for denominator in ["input_data_count", "annotation_count"]
         ]
 
-        columns = (
-            [
-                "date",
-                "cumsum_task_count",
-                "cumsum_input_data_count",
-                "cumsum_actual_worktime_hour",
-                "cumsum_monitored_worktime_hour",
-            ]
-            + production_columns
-            + worktime_columns
-            + velocity_columns
-            + velocity_details_columns
-            + ["working_user_count"]
-        )
+        columns = [
+            "date",
+            "cumsum_task_count",
+            "cumsum_input_data_count",
+            "cumsum_actual_worktime_hour",
+            "cumsum_monitored_worktime_hour",
+            *production_columns,
+            *worktime_columns,
+            *velocity_columns,
+            *velocity_details_columns,
+            "working_user_count",
+        ]
 
         print_csv(self.df[columns], output=str(output_file))
 
@@ -1079,11 +1076,11 @@ class WholeProductivityPerFirstAnnotationStartedDate:
                         get_weekly_sum(df[f"{numerator}_hour"]) * 60 / get_weekly_sum(df[denominator])
                     )
 
-        def create_div_element() -> bokeh.models.Div:
+        def create_div_element() -> Div:
             """
             HTMLページの先頭に付与するdiv要素を生成する。
             """
-            return bokeh.models.Div(
+            return Div(
                 text="""<h4>注意</h4>
                 <p>「X日の作業時間」とは、「X日に教師付開始したタスクにかけた作業時間」です。
                 「X日に作業した時間」ではありません。
@@ -1093,8 +1090,8 @@ class WholeProductivityPerFirstAnnotationStartedDate:
 
         def create_line_graph(title: str, y_axis_label: str, tooltip_columns: list[str]) -> LineGraph:
             return LineGraph(
-                plot_width=1200,
-                plot_height=600,
+                width=1200,
+                height=600,
                 title=title,
                 x_axis_label="教師付開始日",
                 x_axis_type="datetime",
@@ -1142,7 +1139,6 @@ class WholeProductivityPerFirstAnnotationStartedDate:
             return line_graph
 
         def create_input_data_graph() -> LineGraph:
-
             line_graph = create_line_graph(
                 title="教師付開始日ごとの入力データ数と計測作業時間",
                 y_axis_label="入力データ数",
@@ -1262,7 +1258,7 @@ class WholeProductivityPerFirstAnnotationStartedDate:
         source = ColumnDataSource(data=df)
 
         for line_graph, fig_info in zip(line_graph_list, fig_info_list):
-            y_info_list: list[dict[str, str]] = fig_info["y_info_list"]  # type: ignore
+            y_info_list: list[dict[str, str]] = fig_info["y_info_list"]  # type: ignore[assignment]
             for index, y_info in enumerate(y_info_list):
                 color = get_color_from_small_palette(index)
 
@@ -1275,7 +1271,7 @@ class WholeProductivityPerFirstAnnotationStartedDate:
                     color=color,
                 )
 
-        line_graph_list = [create_task_graph(), create_input_data_graph()] + line_graph_list
+        line_graph_list = [create_task_graph(), create_input_data_graph(), *line_graph_list]
 
         for line_graph in line_graph_list:
             line_graph.process_after_adding_glyphs()
