@@ -13,6 +13,7 @@ import annofabapi
 import bokeh
 import bokeh.layouts
 import bokeh.palettes
+import numpy
 import pandas
 from bokeh.plotting import ColumnDataSource
 
@@ -37,7 +38,10 @@ class WorktimePerDate:
     日ごとユーザごとの作業時間情報
     """
 
-    df_dtype = {
+    def __init__(self, df: pandas.DataFrame):
+        self.df = df
+
+    _df_dtype = {
         "date": "string",
         "user_id": "string",
         "username": "string",
@@ -49,23 +53,29 @@ class WorktimePerDate:
         "monitored_acceptance_worktime_hour": "float64",
     }
 
+    def is_empty(self) -> bool:
+        """
+        空のデータフレームを持つかどうかを返します。
+
+        Returns:
+            空のデータフレームを持つかどうか
+        """
+        return len(self.df) == 0
+
     @property
     def columns(self) -> list[str]:
-        return list(self.df_dtype.keys())
-
-    def __init__(self, df: pandas.DataFrame):
-        self.df = df
+        return list(self._df_dtype.keys())
 
     @classmethod
     def from_csv(cls, csv_file: Path) -> WorktimePerDate:
         """CSVファイルからインスタンスを生成します。"""
-        df = pandas.read_csv(str(csv_file), dtype=cls.df_dtype)
+        df = pandas.read_csv(str(csv_file), dtype=cls._df_dtype)
         return cls(df)
 
     @classmethod
     def empty(cls) -> WorktimePerDate:
         """空のデータフレームを持つインスタンスを生成します。"""
-        df = pandas.DataFrame(columns=cls.df_dtype.keys()).astype(cls.df_dtype)
+        df = pandas.DataFrame(columns=cls._df_dtype.keys()).astype(cls._df_dtype)
         return cls(df)
 
     @classmethod
@@ -81,7 +91,7 @@ class WorktimePerDate:
             dict_worktime.values(),
             index=pandas.MultiIndex.from_tuples(dict_worktime.keys(), names=("date", "account_id", "phase")),
         )
-        df = s.unstack()
+        df = s.unstack()  # noqa: PD010 : pandas.Seriesにはpivot_tableがないので、警告を無視する
         df.reset_index(inplace=True)
         df.rename(
             columns={
@@ -232,7 +242,6 @@ class WorktimePerDate:
 
     @classmethod
     def merge(cls, obj1: WorktimePerDate, obj2: WorktimePerDate) -> WorktimePerDate:
-
         df_tmp = pandas.concat([obj1.df, obj2.df])
 
         df = df_tmp.groupby(["date", "user_id"])[
@@ -260,7 +269,7 @@ class WorktimePerDate:
         return True
 
     def _get_default_user_id_list(self) -> list[str]:
-        return list(self.df.sort_values(by=f"date", ascending=False)[f"user_id"].dropna().unique())
+        return list(self.df.sort_values(by="date", ascending=False)["user_id"].dropna().unique())
 
     def _get_continuous_date_dataframe(self) -> pandas.DataFrame:
         """
@@ -289,7 +298,16 @@ class WorktimePerDate:
         df = df.merge(self.df, how="left", on=["date", "user_id"], suffixes=(None, "_tmp"))[self.columns]
 
         # 作業時間関係の列を0で埋める
-        df.fillna(0, inplace=True)
+        df.fillna(
+            {
+                "actual_worktime_hour": 0,
+                "monitored_worktime_hour": 0,
+                "monitored_annotation_worktime_hour": 0,
+                "monitored_inspection_worktime_hour": 0,
+                "monitored_acceptance_worktime_hour": 0,
+            },
+            inplace=True,
+        )
 
         return df
 
@@ -379,6 +397,15 @@ class WorktimePerDate:
         df_cumulative = self._get_cumulative_dataframe(df_continuous_date)
         df_cumulative["dt_date"] = df_cumulative["date"].map(lambda e: datetime.datetime.fromisoformat(e).date())
 
+        # bokeh3.0.3では、string型の列を持つpandas.DataFrameを描画できないため、改めてobject型に戻す
+        # またpandas.NAを持つDataFrameも描画できないので、numpy.nanに変換する
+        # TODO この問題が解決されたら、削除する
+        # https://qiita.com/yuji38kwmt/items/b5da6ed521e827620186
+        df_cumulative = df_cumulative.astype(
+            {"date": "object", "user_id": "object", "username": "object", "biography": "object"}
+        )
+        df_cumulative.replace(pandas.NA, numpy.nan, inplace=True)
+
         line_count = 0
         for user_index, user_id in enumerate(user_id_list):
             df_subset = df_cumulative[df_cumulative["user_id"] == user_id]
@@ -402,12 +429,13 @@ class WorktimePerDate:
 
         graph_group_list = []
         for line_graph in line_graph_list:
-            line_graph.config_legend()
-            hide_all_button = line_graph.create_button_hiding_all_lines()
+            line_graph.process_after_adding_glyphs()
+            hide_all_button = line_graph.create_button_hiding_showing_all_lines(is_hiding=True)
+            show_all_button = line_graph.create_button_hiding_showing_all_lines(is_hiding=False)
             checkbox_group = line_graph.create_checkbox_displaying_markers()
 
-            widgets = bokeh.layouts.column([hide_all_button, checkbox_group])
-            graph_group = bokeh.layouts.row([line_graph.figure, widgets])
+            widgets = bokeh.layouts.column([hide_all_button, show_all_button, checkbox_group])  # type: ignore[list-item] # noqa: E501
+            graph_group = bokeh.layouts.row([line_graph.figure, widgets])  # type: ignore[list-item]
             graph_group_list.append(graph_group)
 
         if line_count == 0:
@@ -420,6 +448,6 @@ class WorktimePerDate:
         if not self._validate_df_for_output(output_file):
             return
 
-        columns = self.df_dtype.keys()
+        columns = self._df_dtype.keys()
 
         print_csv(self.df[columns], output=str(output_file))
