@@ -186,14 +186,13 @@ class DeleteSupplementaryDataMain(AbstractCommandLineWithConfirmInterface):
         for input_data_id in input_data_id_list:
             input_data = self.service.wrapper.get_input_data_or_none(project_id, input_data_id)
             if input_data is None:
-                logger.warning(f"input_data_id={input_data_id} の入力データは存在しません。")
-                input_data_name = None
-            else:
-                input_data_name = input_data["input_data_name"]
+                logger.warning(f"input_data_id={input_data_id} の入力データは存在しないので、補助情報の削除をスキップします。")
+                continue
+            input_data_name = input_data["input_data_name"]
 
             supplementary_data_list, _ = self.service.api.get_supplementary_data_list(project_id, input_data_id)
             if len(supplementary_data_list) == 0:
-                logger.debug(f"入力データに紐づく補助情報は存在しないので、削除をスキップします。")
+                logger.debug("入力データに紐づく補助情報は存在しないので、削除をスキップします。")
                 continue
 
             message_for_confirm = (
