@@ -12,7 +12,6 @@ from annofabapi.models import ProjectMemberRole, TaskStatus
 
 import annofabcli
 import annofabcli.common.cli
-from annofabcli import AnnofabApiFacade
 from annofabcli.common.cli import (
     COMMAND_LINE_ERROR_STATUS_CODE,
     AbstractCommandLineInterface,
@@ -20,7 +19,7 @@ from annofabcli.common.cli import (
     build_annofabapi_resource_and_login,
     prompt_yesnoall,
 )
-from annofabcli.common.facade import TaskQuery, match_task_with_query
+from annofabcli.common.facade import AnnofabApiFacade, TaskQuery, match_task_with_query
 
 logger = logging.getLogger(__name__)
 
@@ -66,9 +65,12 @@ class ChangeOperatorMain:
         task_query: Optional[TaskQuery] = None,
         task_index: Optional[int] = None,
     ) -> bool:
-
         logging_prefix = f"{task_index+1} 件目" if task_index is not None else ""
-        dict_task, _ = self.service.api.get_task(project_id, task_id)
+        dict_task = self.service.wrapper.get_task_or_none(project_id, task_id)
+        if dict_task is None:
+            logger.warning(f"{logging_prefix}: task_id='{task_id}'のタスクは存在しないので、スキップします。")
+            return False
+
         task: Task = Task.from_dict(dict_task)
 
         now_user_id = None
@@ -98,13 +100,12 @@ class ChangeOperatorMain:
 
         try:
             # 担当者を変更する
-            self.facade.change_operator_of_task(project_id, task_id, new_account_id)
+            self.service.wrapper.change_task_operator(project_id, task_id, operator_account_id=new_account_id)
             logger.debug(f"{logging_prefix} : task_id = {task_id}, phase={dict_task['phase']} のタスクの担当者を変更しました。")
             return True
 
-        except requests.exceptions.HTTPError as e:
-            logger.warning(f"{logging_prefix} : task_id = {task_id} の担当者を変更するのに失敗しました。")
-            logger.warning(e)
+        except requests.exceptions.HTTPError:
+            logger.warning(f"{logging_prefix} : task_id = {task_id} の担当者を変更するのに失敗しました。", exc_info=True)
             return False
 
     def change_operator_for_task_wrapper(
@@ -115,13 +116,17 @@ class ChangeOperatorMain:
         new_account_id: Optional[str] = None,
     ) -> bool:
         task_index, task_id = tpl
-        return self.change_operator_for_task(
-            project_id=project_id,
-            task_id=task_id,
-            task_index=task_index,
-            task_query=task_query,
-            new_account_id=new_account_id,
-        )
+        try:
+            return self.change_operator_for_task(
+                project_id=project_id,
+                task_id=task_id,
+                task_index=task_index,
+                task_query=task_query,
+                new_account_id=new_account_id,
+            )
+        except Exception:  # pylint: disable=broad-except
+            logger.warning(f"タスク'{task_id}'の担当者の変更に失敗しました。", exc_info=True)
+            return False
 
     def change_operator(
         self,
@@ -148,10 +153,10 @@ class ChangeOperatorMain:
                 logger.error(f"ユーザ '{new_user_id}' のaccount_idが見つかりませんでした。終了します。")
                 return
             else:
-                logger.info(f" {len(task_id_list)}のタスクの担当者を、{new_user_id}に変更します。")
+                logger.info(f"{len(task_id_list)} 件のタスクの担当者を、{new_user_id}に変更します。")
         else:
             new_account_id = None
-            logger.info(f" {len(task_id_list)} 件のタスクの担当者を未割り当てに変更します。")
+            logger.info(f"{len(task_id_list)} 件のタスクの担当者を未割り当てに変更します。")
 
         success_count = 0
 
@@ -169,11 +174,15 @@ class ChangeOperatorMain:
         else:
             # 逐次処理
             for task_index, task_id in enumerate(task_id_list):
-                result = self.change_operator_for_task(
-                    project_id, task_id, task_index=task_index, task_query=task_query, new_account_id=new_account_id
-                )
-                if result:
-                    success_count += 1
+                try:
+                    result = self.change_operator_for_task(
+                        project_id, task_id, task_index=task_index, task_query=task_query, new_account_id=new_account_id
+                    )
+                    if result:
+                        success_count += 1
+                except Exception:  # pylint: disable=broad-except
+                    logger.warning(f"タスク'{task_id}'の担当者の変更に失敗しました。", exc_info=True)
+                    continue
 
         logger.info(f"{success_count} / {len(task_id_list)} 件 タスクの担当者を変更しました。")
 
@@ -203,7 +212,7 @@ class ChangeOperator(AbstractCommandLineInterface):
         elif args.not_assign:
             user_id = None
         else:
-            logger.error(f"タスクの担当者の指定方法が正しくありません。")
+            logger.error("タスクの担当者の指定方法が正しくありません。")
             return
 
         dict_task_query = annofabcli.common.cli.get_json_from_args(args.task_query)
