@@ -13,6 +13,7 @@ import annofabapi.utils
 import requests
 from annofabapi.dataclass.task import Task
 from annofabapi.models import InputDataType, ProjectMemberRole, TaskPhase, TaskStatus
+from annofabapi.plugin import EditorPluginId
 
 import annofabcli
 import annofabcli.common.cli
@@ -83,7 +84,7 @@ class RejectTasksMain(AbstractCommandLineWithConfirmInterface):
         elif assigned_annotator_user_id is not None:
             confirm_message += f"ユーザ '{assigned_annotator_user_id}' を担当者に割り当てます。"
         else:
-            confirm_message += f"担当者は割り当てません。"
+            confirm_message += "担当者は割り当てません。"
 
         return self.confirm_processing(confirm_message)
 
@@ -404,15 +405,18 @@ class RejectTasks(AbstractCommandLineInterface):
                 # 注意：少なくとも0.1秒以上の区間にしないと、Annofab上で検査コメントを確認できない
                 comment_data = {"start": 0, "end": 100, "_type": "Time"}
             elif project["input_data_type"] == InputDataType.CUSTOM.value:
-                # customプロジェクト
-                if custom_project_type == CustomProjectType.THREE_DIMENSION_POINT_CLOUD:
+                editor_plugin_id = project["configuration"]["plugin_id"]
+                if (
+                    editor_plugin_id == EditorPluginId.THREE_DIMENSION.value
+                    or custom_project_type == CustomProjectType.THREE_DIMENSION_POINT_CLOUD
+                ):
                     comment_data = {
                         "data": '{"kind": "CUBOID", "shape": {"dimensions": {"width": 1.0, "height": 1.0, "depth": 1.0}, "location": {"x": 0.0, "y": 0.0, "z": 0.0}, "rotation": {"x": 0.0, "y": 0.0, "z": 0.0}, "direction": {"front": {"x": 1.0, "y": 0.0, "z": 0.0}, "up": {"x": 0.0, "y": 0.0, "z": 1.0}}}, "version": "2"}',  # noqa: E501
                         "_type": "Custom",
                     }
                 else:
                     print(
-                        f"{self.COMMON_MESSAGE}: カスタムプロジェクトに検査コメントを付与する場合は、'--comment_data' または '--custom_project_type'を指定してください。",  # noqa: E501
+                        f"{self.COMMON_MESSAGE}: カスタムプロジェクト（ビルトインのエディタプラグインを使用していない）に検査コメントを付与する場合は、'--comment_data' または '--custom_project_type'を指定してください。",  # noqa: E501
                         file=sys.stderr,
                     )
                     sys.exit(COMMAND_LINE_ERROR_STATUS_CODE)
@@ -447,7 +451,8 @@ def parse_args(parser: argparse.ArgumentParser):
         "-c",
         "--comment",
         type=str,
-        help="差し戻すときに付与する検査コメントを指定します。検査コメントはタスク内の先頭画像に付与します。付与する位置は ``--comment_data`` で指定できます。",
+        help="差し戻すときに付与する検査コメントを指定します。検査コメントはタスク内の先頭画像に付与します。付与する位置は ``--comment_data`` で指定できます。\n"
+        "未指定の場合は、検査コメントを付与せずに差し戻します。",
     )
 
     parser.add_argument(
@@ -467,8 +472,7 @@ def parse_args(parser: argparse.ArgumentParser):
         "--custom_project_type",
         type=str,
         choices=[e.value for e in CustomProjectType],
-        help="[BETA] カスタムプロジェクトの種類を指定します。カスタムプロジェクトに対して、検査コメントの位置を指定しない場合は必須です。\n"
-        "※ Annofabの情報だけでは'3dpc'プロジェクトかどうかが分からないため、指定する必要があります。",
+        help="[BETA] カスタムプロジェクトの種類を指定します。ビルトインのエディタプラグインを使用していないカスタムプロジェクトに対して、検査コメントの位置を指定しない場合は必須です。\n",
     )
 
     # 差し戻したタスクの担当者の割当に関して
